<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Data::SyncthingConnection</name>
    <message>
        <location filename="../syncthingconnection.cpp" line="175"/>
        <source>disconnected</source>
        <translation>Verbindung getrennt</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="177"/>
        <source>reconnecting</source>
        <translation>Verbindung wird hergestellt</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="179"/>
        <source>connected</source>
        <translation>verbunden</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="181"/>
        <source>connected, scanning</source>
        <translation>verbunden, scannt</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="183"/>
        <source>connected, paused</source>
        <translation>verbunden, pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="185"/>
        <source>connected, synchronizing</source>
        <translation>verbunden, am Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="187"/>
        <source>connected, remote not in sync</source>
        <translation>verbunden, entferntes Gerät nicht synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="798"/>
        <source>Unable to parse timestamp &quot;%1&quot; (%2): %3</source>
        <translation>Fehler beim Parsen des Zeitstempels &quot;%1&quot; (Kontext: &quot;%2&quot;): %3</translation>
    </message>
    <message>
        <source>connected, out of sync</source>
        <translation type="vanished">verbunden, nicht synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="189"/>
        <source>unknown</source>
        <translation>Verbindungsstatus unbekannt</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="340"/>
        <location filename="../syncthingconnection.cpp" line="530"/>
        <source>Connection configuration is insufficient.</source>
        <translation>Verbindungskonfiguration is ungenügend</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="533"/>
        <source>Unable to rescan: No folder ID specified.</source>
        <translation>Fehler beim Anfordern eines Scans: keine Ordner-ID angegeben.</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="350"/>
        <source>Unable to pause/resume a devices when not connected</source>
        <translation>Fehler beim Anfordern Ordner zu Pausieren/Fortzusetzen</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="465"/>
        <source>Unable to pause/resume a folders when not connected</source>
        <translation>Fehler beim Anfordern Gerät zu Pausieren/Fortzusetzen</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1465"/>
        <source>Unable to request QR-Code: </source>
        <translation>Fehler beim Abfragen des QR-Codes: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1498"/>
        <source>Unable to parse Syncthing log: </source>
        <translation>Fehler beim Auslesen des Syncthing-Logs: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1515"/>
        <source>Unable to request Syncthing log: </source>
        <translation>Fehler beim Abfragen des Syncthing-Logs: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="871"/>
        <source>Unable to locate certificate used by Syncthing.</source>
        <translation>Das SSL-Zertifikat von Syncthing kann nicht gefunden werden.</translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="877"/>
        <source>Unable to load certificate used by Syncthing.</source>
        <translation>Das SSL-Zertifikat von Syncthing kann nicht ausgelesen werden.</translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="688"/>
        <source>Unable to parse Syncthing config: </source>
        <translation>Fehler beim Auslesen der Syncthing-Konfiguration: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="710"/>
        <source>Unable to request Syncthing config: </source>
        <translation>Fehler beim Abfragen der Syncthing-Konfiguration: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="839"/>
        <source>Unable to parse Syncthing status: </source>
        <translation>Fehler beim Auslesen des Syncthing-Status: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="858"/>
        <source>Unable to request Syncthing status: </source>
        <translation>Fehler beim Abfragen des Syncthing-Status: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="906"/>
        <source>Unable to parse connections: </source>
        <translation>Fehler beim Auslesen der Verbindungen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="983"/>
        <source>Unable to request connections: </source>
        <translation>Fehler beim Abfragen der Verbindungen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1081"/>
        <source>Unable to parse folder statistics: </source>
        <translation>Fehler beim Auslesen der Ordnerstatistiken: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1132"/>
        <location filename="../syncthingconnection_requests.cpp" line="1190"/>
        <source>Unable to request folder statistics: </source>
        <translation>Fehler beim Abfragen der Ordnerstatistiken: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1361"/>
        <source>Unable to parse device statistics: </source>
        <translation>Fehler beim Auslesen der Gerätestatistiken: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1388"/>
        <source>Unable to request device statistics: </source>
        <translation>Fehler beim Abfragen der Gerätestatistiken: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1021"/>
        <source>Unable to parse errors: </source>
        <translation>Fehler beim Auslesen der Syncthing-Fehlermeldungen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1049"/>
        <source>Unable to request errors: </source>
        <translation>Fehler beim Abfragen der Syncthing-Fehlermeldungen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="654"/>
        <source>Unable to request clearing errors: </source>
        <translation>Fehler beim Löschen der Fehlermeldungen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1894"/>
        <source>Unable to parse Syncthing events: </source>
        <translation>Fehler beim Auslesen der Syncthing-Ereignisse: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1921"/>
        <source>Unable to request Syncthing events: </source>
        <translation>Fehler beim Abfragen der Syncthing-Ereignisse: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1718"/>
        <source>Unable to post config: </source>
        <translation>Fehler beim Senden der neuen Konfiguration: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="563"/>
        <source>Unable to request rescan: </source>
        <translation>Fehler beim Anfordern eines Ordner-Rescans: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="398"/>
        <source>Unable to request device pause/resume: </source>
        <translation>Fehler beim Anfordern Gerät zu Pausieren/Fortzusetzen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="502"/>
        <source>Unable to request folder pause/resume: </source>
        <translation>Fehler beim Anfordern Ordner zu Pausieren/Fortzusetzen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="594"/>
        <source>Unable to request restart: </source>
        <translation>Fehler beim Anfordern eines Neustarts: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="623"/>
        <source>Unable to request shutdown: </source>
        <translation>Fehler beim Anfordern Syncthing zu beenden: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1175"/>
        <source>Unable to parse status for folder %1: </source>
        <translation>Fehler beim Auslesen des Status von Ordner %1: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1238"/>
        <source>Unable to parse pull errors for folder %1: </source>
        <translation>Fehler beim Auslesen der Fehler von Ordner %1: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1248"/>
        <source>Unable to request pull errors for folder %1: </source>
        <translation>Fehler beim Anfordern der Fehler von Ordner %1: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1314"/>
        <source>Unable to parse completion for device/folder %1/%2: </source>
        <translation>Fehler beim Auslesen des Fortschrittes von Ordner %1/%2: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1329"/>
        <source>Unable to request completion for device/folder %1/%2: </source>
        <translation>Fehler beim Anfordern des Fortschrittes von Ordner %1/%2: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1416"/>
        <source>Unable to parse version: </source>
        <translation>Fehler beim Auslesen der Syncthing-Version: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1430"/>
        <source>Unable to request version: </source>
        <translation>Fehler beim Anfordern der Syncthing-Version: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1548"/>
        <source>Unable to request directory override: </source>
        <translation>Fehler Überschreiben: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1581"/>
        <source>Unable to request directory revert: </source>
        <translation>Fehler beim Zurücksetzen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1660"/>
        <source>Unable to parse response for browsing &quot;%1&quot;: </source>
        <translation>Fehler beim Auslesen der Inhalte des Ordners &quot;%1&quot;: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="1674"/>
        <source>Unable to browse &quot;%1&quot;: </source>
        <translation>Fehler beim Durchsuchen des Ordners &quot;%1&quot;: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2502"/>
        <source>Unable to parse disk events: </source>
        <translation>Fehler beim Auslesen der letzten Änderungen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection_requests.cpp" line="2525"/>
        <source>Unable to request disk events: </source>
        <translation>Fehler beim Anfordern der letzten Änderungen: </translation>
    </message>
    <message>
        <location filename="../syncthingconnection.cpp" line="1070"/>
        <source>at offset %1</source>
        <translation>bei Zeichen %1</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingNotifier</name>
    <message>
        <location filename="../syncthingnotifier.cpp" line="82"/>
        <source>Device %1 (%2) wants to connect.</source>
        <translation>Gerät %1 (%2) möchte sich verbinden.</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="96"/>
        <source>Device </source>
        <translation>Gerät </translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="96"/>
        <source>Unknown device </source>
        <translation>Unbekanntes Gerät </translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="98"/>
        <source> wants to share folder %1.</source>
        <translation> möchte den Ordner %1 teilen.</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="100"/>
        <source> wants to share folder %1 (%2).</source>
        <translation> möchte den Ordner %1 (%2) teilen.</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="115"/>
        <source>Failed to start Syncthing</source>
        <translation>Fehler beim Starten von Syncthing</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="116"/>
        <source>Maybe the configured binary path is wrong or the binary is not marked as executable.</source>
        <translation>Vielleicht ist der konfigurierte Pfad zu Syncthing falsch oder die Datei nicht als ausführbar markiert.</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="119"/>
        <source>Syncthing crashed</source>
        <translation>Syncthing ist abgestürtzt</translation>
    </message>
    <message>
        <source>Syncthing crashed with exit code %1</source>
        <translation type="vanished">Syncthing ist mit dem Exit-Code %1 abgestürtzt</translation>
    </message>
    <message>
        <location filename="../syncthingnotifier.cpp" line="122"/>
        <source>Syncthing launcher error occurred</source>
        <translation>Bei der Ausführung von Syncthing ist ein Fehler aufgetreten</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingService</name>
    <message>
        <location filename="../syncthingservice.cpp" line="378"/>
        <source>start unit</source>
        <translation>Starten der Unit</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="380"/>
        <source>stop unit</source>
        <translation>Stoppen der Unit</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="395"/>
        <source>enable unit</source>
        <translation>Aktivieren der Unit</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="397"/>
        <source>disable unit</source>
        <translation>Deaktivieren der Unit</translation>
    </message>
    <message>
        <location filename="../syncthingservice.cpp" line="407"/>
        <source>reload all unit files</source>
        <translation>Aktualisieren aller Unit-Dateien</translation>
    </message>
</context>
<context>
    <name>Data::Utils</name>
    <message>
        <location filename="../utils.cpp" line="30"/>
        <source>%1 ago</source>
        <translation>vor %1</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="33"/>
        <source>right now</source>
        <translation>gerade eben</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="44"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message numerus="yes">
        <location filename="../utils.cpp" line="60"/>
        <source>%1 file(s)</source>
        <translation>
            <numerusform>%1 Datei</numerusform>
            <numerusform>%1 Dateien</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../utils.cpp" line="61"/>
        <source>%1 dir(s)</source>
        <translation>
            <numerusform>%1 Verz.</numerusform>
            <numerusform>%1 Verz.</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="76"/>
        <source>Synchronization of local folder %1 complete</source>
        <translation>%1 wurde lokal synchronisiert</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="84"/>
        <source>Synchronization of the following local folders complete:
</source>
        <translation>Folgende Ordner wurden lokal synchronisiert:
</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="98"/>
        <source>file system watcher and periodic rescan disabled</source>
        <translation>Dateisystemüberwachung und periodischer Scan deaktiviert</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="100"/>
        <source>file system watcher active, periodic rescan disabled</source>
        <translation>Dateisystemüberwachung aktiv, periodischer Scan deaktiviert</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="103"/>
        <source>, file system watcher enabled</source>
        <translation>, Dateisystemüberwachung aktiviert</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="104"/>
        <source>, file system watcher disabled</source>
        <translation>, Dateisystemüberwachung deaktiviert</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="79"/>
        <source>Synchronization of %1 on %2 complete</source>
        <translation>%1 wurde auf %2 synchronisiert</translation>
    </message>
    <message>
        <location filename="../utils.cpp" line="87"/>
        <source>Synchronization of the following folders on %1 complete:
</source>
        <translation>Folgende Ordner wurden auf %1 synchronisiert:
</translation>
    </message>
</context>
<context>
    <name>SyncthingDev</name>
    <message>
        <location filename="../syncthingdev.cpp" line="32"/>
        <source>paused</source>
        <translation>pausiert</translation>
    </message>
</context>
<context>
    <name>SyncthingDevStatus</name>
    <message>
        <location filename="../syncthingdev.cpp" line="11"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="13"/>
        <source>disconnected</source>
        <translation>getrennt</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="15"/>
        <source>this device</source>
        <translation>dieses Gerät</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="17"/>
        <source>idle</source>
        <translation>untätig</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="19"/>
        <source>synchronizing</source>
        <translation>synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="21"/>
        <source>out of sync</source>
        <translation>nicht synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingdev.cpp" line="23"/>
        <source>rejected</source>
        <translation>zurückgewiesen</translation>
    </message>
</context>
<context>
    <name>SyncthingDir</name>
    <message>
        <location filename="../syncthingdir.cpp" line="174"/>
        <source>paused</source>
        <translation>pausiert</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="176"/>
        <source>unshared</source>
        <translation>nicht geteilt</translation>
    </message>
</context>
<context>
    <name>SyncthingDirStatus</name>
    <message>
        <location filename="../syncthingdir.cpp" line="17"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="19"/>
        <source>idle</source>
        <translation>untätig</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="23"/>
        <source>waiting to scan</source>
        <translation>wartet aufs Scannen</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="21"/>
        <source>scanning</source>
        <translation>scannt</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="25"/>
        <source>waiting to sync</source>
        <translation>wartet aufs Synchronisieren</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="27"/>
        <source>preparing to sync</source>
        <translation>bereitet Synchronisation vor</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="29"/>
        <source>synchronizing</source>
        <translation>synchronisiert</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="31"/>
        <source>cleaning</source>
        <translation>Versionen bereinigen</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="33"/>
        <source>waiting to clean</source>
        <translation>wartet auf Bereinigung</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="35"/>
        <source>out of sync</source>
        <translation>nicht synchronisiert</translation>
    </message>
</context>
<context>
    <name>SyncthingDirType</name>
    <message>
        <location filename="../syncthingdir.cpp" line="44"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="46"/>
        <source>Send &amp; Receive</source>
        <translation>Senden &amp; Empfangen</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="48"/>
        <source>Send only</source>
        <translation>Nur senden</translation>
    </message>
    <message>
        <location filename="../syncthingdir.cpp" line="50"/>
        <source>Receive only</source>
        <translation>Nur empfangen</translation>
    </message>
</context>
</TS>
